(ns puppetlabs.redrover.schema
  (:require [schema.core :as sc]
            [puppetlabs.classifier.schema :refer [Group]]))

(def OldGroup
  "Schema for exported 3.3 dashboard classification groups."
  {:name sc/Str
   :description sc/Str
   :parents [sc/Str]
   :nodes [sc/Str]
   :variables {sc/Keyword sc/Any}
   :classes {sc/Keyword {sc/Keyword sc/Any}}})

(def OldNode
  "Old 3.3 dashboard classification nodes are exported with the same schema as
  dashboard groups. The only difference is that are some restrictions on the
  fields:
    * the :parents field must be an empty vector.
    * the :nodes field is always a vector with a single node's name."
  (assoc OldGroup
         :parents (sc/eq [])
         :nodes (sc/pred #(= (count %) 1) "one node name")))

(def DashboardExport
  "A complete export of a PE 3.3 dashboard classification."
  {:groups [OldGroup]
   :nodes [OldNode]})

(def ConvertedHierarchy
  [Group])
